@@ -14,7 +14,7 @@ log = logging.getLogger(sys.modules[__name__].__name__)
 class ConfigCatClient(object):
 
     def __init__(self,
-                 api_key,
+                 sdk_key,
                  poll_interval_seconds=60,
                  max_init_wait_time_seconds=5,
                  on_configuration_changed_callback=None,
@@ -24,10 +24,10 @@ class ConfigCatClient(object):
                  proxies=None,
                  proxy_auth=None):
 
-        if api_key is None:
-            raise ConfigCatClientException('API Key is required.')
+        if sdk_key is None:
+            raise ConfigCatClientException('SDK Key is required.')
 
-        self._api_key = api_key
+        self._sdk_key = sdk_key
         self._rollout_evaluator = RolloutEvaluator()
 
         if config_cache_class:
@@ -36,16 +36,16 @@ class ConfigCatClient(object):
             self._config_cache = InMemoryConfigCache()
 
         if poll_interval_seconds > 0:
-            self._config_fetcher = ConfigFetcher(api_key, 'p', base_url, proxies, proxy_auth)
+            self._config_fetcher = ConfigFetcher(sdk_key, 'p', base_url, proxies, proxy_auth)
             self._cache_policy = AutoPollingCachePolicy(self._config_fetcher, self._config_cache,
                                                         poll_interval_seconds, max_init_wait_time_seconds,
                                                         on_configuration_changed_callback)
         elif cache_time_to_live_seconds > 0:
-            self._config_fetcher = ConfigFetcher(api_key, 'l', base_url, proxies, proxy_auth)
+            self._config_fetcher = ConfigFetcher(sdk_key, 'l', base_url, proxies, proxy_auth)
             self._cache_policy = LazyLoadingCachePolicy(self._config_fetcher, self._config_cache,
                                                         cache_time_to_live_seconds)
         else:
-            self._config_fetcher = ConfigFetcher(api_key, 'm', base_url, proxies, proxy_auth)
+            self._config_fetcher = ConfigFetcher(sdk_key, 'm', base_url, proxies, proxy_auth)
             self._cache_policy = ManualPollingCachePolicy(self._config_fetcher, self._config_cache)
 
     def get_value(self, key, default_value, user=None):
